Randomizer

General Settings
Beep probability: %
Shock probability: %
Pause min: s
Pause max: s
Start delay min: minutes
Start delay max: minutes
Runtime min: minutes
Runtime max: minutes
Beep all receivers on startup:
Default values, which may be overwritten below:
Shock min duration: ms
Shock max duration: ms
Shock min power: %
Shock max power: %
Beep shock delay: ms
Receiver specific settings

Status:
(when this page was last refreshed).